Method: CodeRay.encode_stream
- Defined in:
- lib/coderay.rb
.encode_stream(code, lang, format, options = {}) ⇒ Object
Encode a string in Streaming mode.
This starts scanning code with the the Scanner for lang while encodes the output with the Encoder for format. options will be passed to the Encoder.
See CodeRay::Encoder.encode_stream
195 196 197 |
# File 'lib/coderay.rb', line 195 def encode_stream code, lang, format, = {} encoder(format, ).encode_stream code, lang, end |